/*
 * Called when the preference window loads.  Populates the Schedules List
 * based on the "extensions.hpsched.schedules" preference.
 */
function populatePrefpane() 
{
    /* run initialiser function for the OFM Domain setting */
    initOFMDomain();

	/* run initialiser functions */
	//FEATURE DEACTIVATED initTooltipOfmArm();

	/* load Add-on website from preferences and visualise in "Add-on-Preference" pop-up */
	var newsite=prefBranchAbout.get("website");
	document.getElementById("website").setAttribute("value", newsite);
	document.getElementById("website").setAttribute("href", newsite);			

	/* workaround for Linux: OK button is not shown by default */
	document.documentElement.getButton("accept").hidden = false;
}

function initTooltipOfmArm()
{
	document.getElementById("ttOfmArm").setAttribute("src", prefBranchOFMFunctionSettings.get("arm.urlnewimage"));
}

function initOFMDomain()
{
    try
    {
        if(foxfm_isConfigurationDatabaseActivated())
        {
            /* change the 'datasource' of the template to the path of the configuration
            database of the addon */
            var sPathToConfigDB;
            sPathToConfigDB = "file://" + foxfm_getPathToConfigurationDatabase().path;
            //sPathToConfigDB = "chrome://foxfm/defaults/database/foxfm_configuration.sqlite";
            infoMessage(2, "populatePrefpane(): path to config DB: " + sPathToConfigDB);
            document.getElementById("lbOFMDomain").setAttribute("datasources", sPathToConfigDB);
            document.getElementById("lbOFMDomainLocalisation").setAttribute("datasources", sPathToConfigDB);
            /* WORKAROUND:  As the 'datasource' of the template is changed by script
                            I assume there is a problem in loading the information 
                            from the preference system. Therefore this script gets the
                            current preference and initilises the XUL element. */
            var sOFMDomain              = foxfm_getPrefOFMDomain();
            var sOFMDomainLocalisation  = foxfm_getPrefOFMDomainLocalisation();
            document.getElementById("lbOFMDomain").setAttribute("value", sOFMDomain);
            document.getElementById("lbOFMDomain").setAttribute("label", sOFMDomain);
            document.getElementById("lbOFMDomainLocalisation").setAttribute("value", sOFMDomainLocalisation);
            document.getElementById("lbOFMDomainLocalisation").setAttribute("label", sOFMDomainLocalisation);
            /* Activate the domain settings only if the configuration database 
             * is activated */
            document.getElementById("hboxOFMDomain").setAttribute("hidden", "false");
        }
    } catch(e) {
        errorMessage(e);
    }
}

function onAcceptanceOptions()
{
	infoMessage(2, "onAcceptanceOptions");

	var maxStrengthlevel = prefBranchOFMStrengthLevel.get("maxlevel");
	for(var i=1; i<=maxStrengthlevel; i++)
	{		
		var strengthlevel = i;
		var prefPanelStrengthlevel = document.getElementById("tbStrlvl" + strengthlevel);
		
		if(prefPanelStrengthlevel)
		{
			var strengthlevelPoints = prefPanelStrengthlevel.value;
			var prefStrengthlevel = i;
			infoMessage(2, "update AWP Level Pref '" + prefStrengthlevel + "': " + strengthlevelPoints);
			prefBranchOFMStrengthLevel.set(prefStrengthlevel, strengthlevelPoints);
		}
	}
}

function foxfm_createNewDatabase()
{
	try
	{
		infoMessage(4, "foxfm_createNewDatabase(): started");

		var defaultDatabase	= foxfm_getPathToDefaultDatabase();
		var newDatabase		= saveNsIFile("Give path and name to your new Database...", "SQLite Database (*.sqlite)", "*.sqlite")
		if(newDatabase)
		{
			infoMessage(0, "foxfm_createNewDatabase(): new database: " + newDatabase.parent.path + "/" + newDatabase.leafName);
			if(newDatabase.exists()) {
				if(newDatabase.isWritable()) {
					newDatabase.remove(false);
				} else {
					alert("foxfm_createNewDatabase(): Access denied: " + newDatabase.path);
				}
			}
			defaultDatabase.copyTo(newDatabase.parent, newDatabase.leafName);
			prefBranchAddOn.set("pathtodatabase", newDatabase.path);			
		} else {
			infoMessage("foxfm_createNewDatabase(): Did not create new Database.");
		}
	} catch(e) {
		errorMessage(e);
	}
}

function foxfm_getPathToDefaultDatabase()
{
	var defaultDatabase = null;
	try
	{
		infoMessage(4, "foxfm_getPathToDefaultDatabase(): started");

		// path to default directory of the addon and the name of the default database
		defaultDatabase = FileUtils.getFile("ProfD", ["extensions", "foxfm@foxfm.org", "defaults", "foxfm.sqlite"]);
		
		if (!defaultDatabase.exists() || !defaultDatabase.isFile()) {
			errorMessage("foxfm_getPathToDefaultDatabase(): Could not get default database.");
		} else {
			infoMessage(4, "foxfm_getPathToDefaultDatabase(): finished: " + defaultDatabase.path);
		}
	} catch(e) {
		errorMessage(e);
	}
	return defaultDatabase;
}

function foxfm_setPathToDatabase()
{
	try
	{
		infoMessage(4, "foxfm_setPathToDatabase(): started");

		pathToDatabase =	getNsIFile("Chose your database...", "SQLite Database (*.sqlite)", "*.sqlite");
		
		if (!pathToDatabase.exists() || !pathToDatabase.isFile()) {
			errorMessage("foxfm_setPathToDatabase(): Could not set database.");
		} else {
			infoMessage(4, "foxfm_setPathToDatabase(): finished: " + pathToDatabase.path);
			prefBranchAddOn.set("pathtodatabase", pathToDatabase.path);			
		}
	} catch(e) {
		errorMessage(e);
	}
}
