/*******************************************************************************
 * Name of function:		foxfm_tm_handling()
 * Arguments of function:	document
 * Description of function:	This function checks if the transfermarket handling
 *							support is activated. The activated functions are
 *							executed by sub-functions called by this one.
 */
function foxfm_tm_handling(document)
{
	try 
	{
		infoMessage(2, "foxfm_tm_handling(): started");

		// add default transfer market duration
		foxfm_tm_defaultDuration(document);		
		
		// add default transfer market price
		foxfm_tm_defaultPrice(document);
		
		// add adding player (half)automatically to the transfer market
		foxfm_tm_logbook(document);
	} catch (e) {
		errorMessage(e);
	}
}

/*******************************************************************************
 * Name of function:		foxfm_tm_defaultDuration()
 * Arguments of function:	document
 * Description of function:	This function sets the duration how long a player 
 *							will be put on the transfer market by a default
 *							value.
 */
function foxfm_tm_defaultDuration(document)
{
	try 
	{
		var addDefaultTMDuration = prefBranchOFMFunctionSettings.get("transfermarket.adddefaultduration");
	
		if((document.location.href.match("010_mannschaft/spieler_anbieten_small.php") || 
		    document.location.href.match("010_transfer/angebote.php")) && addDefaultTMDuration) 
		{
			infoMessage(3, "foxfm_tm_defaultDuration(): started");
			
			// get default transfer marktet duration from the preferences
			var defaultTMDuration = getNumberFromString(prefBranchOFMFunctionSettings.get("transfermarket.defaultduration"));
			
			foxfm_tm_setInitialDuration(document, 7-defaultTMDuration);
			
			// save last used TM duration as default duration
			var saveLastDuration = prefBranchOFMFunctionSettings.get("transfermarket.defaultdurationsavelast");
			if(saveLastDuration)
			{
				var TMSubmit = foxfm_tm_getElementSubmit(document);
				if(TMSubmit)
				{
					TMSubmit.addEventListener("mouseup", function(){event_tm_saveLastDuration(document)}, false);
				}
			}
		}
	} catch (e) {
		errorMessage(e);
	}
}

function foxfm_tm_getElementSubmit(document)
{
	var elementTMSubmit = null;
	try
	{
		infoMessage(4, "foxfm_tm_getElementSubmit(): started");

		if((document.location.href.match("010_mannschaft/spieler_anbieten_small.php") || 
		   document.location.href.match("010_transfer/angebote.php"))) 
		{
			var aInputs = document.getElementsByTagName("input");
			for(var i=0; i<aInputs.length; i++)
			{
				var aInputType= aInputs[i].type;				
				if(aInputType.match("submit"))
				{
					var aInputName= aInputs[i].name;
					infoMessage(4, "foxfm_tm_getElementSubmit(): aInputName: " + aInputName);
					if(aInputName.match("anbieten") || aInputName.match("drauf"))
					{
						elementTMSubmit = aInputs[i];
						break;
					}
				}				
			}
		}
	} catch (e) {
		errorMessage(e);
	}	
	return elementTMSubmit;
}

function foxfm_tm_getInitialDuration(document)
{
	var initialDuration = null;
	try
	{
		var elementInitialDuration = foxfm_tm_getElementInitialDuration(document);
		if(elementInitialDuration)
		{
			for(var i=0; i<elementInitialDuration.options.length; i++)
			{
				var selected = elementInitialDuration.options[i].selected;
				if(selected)
				{
					initialDuration = getNumberFromString(elementInitialDuration.options[i].text);
					infoMessage(4, "foxfm_tm_getInitialDuration(): initial duration: " + initialDuration);
				}
			}
		}
	} catch (e) {
		errorMessage(e);
	}
	return initialDuration;
}

function foxfm_tm_setInitialDuration(document, duration)
{
	try
	{
		var elementInitialDuration = foxfm_tm_getElementInitialDuration(document);
		if(elementInitialDuration)
		{
			elementInitialDuration.options[duration].selected = true;
		}
	} catch (e) {
		errorMessage(e);
	}
}

function foxfm_tm_getElementInitialDuration(document)
{
	var elementTMSelectInitialDuration = null;
	try
	{
		infoMessage(4, "foxfm_tm_getElementInitialDuration(): started");

		if((document.location.href.match("010_mannschaft/spieler_anbieten_small.php") || 
		    document.location.href.match("010_transfer/angebote.php"))) 
		{
			var aSelects = document.getElementsByTagName("select");
			for(var i=0; i<aSelects.length; i++)
			{				
				var aSelectName= aSelects[i].name;
				infoMessage(4, "foxfm_tm_getElementInitialDuration(): aSelectName: " + aSelectName);
				if(aSelectName.match("startwoche"))
				{
					elementTMSelectInitialDuration = aSelects[i];
					break;
				}								
			}
		}
	} catch (e) {
		errorMessage(e);
	}	
	return elementTMSelectInitialDuration;
}

function event_tm_saveLastDuration(document)
{
	try
	{
		infoMessage(4, "event_tm_saveLastDuration(): started");

		var duration = foxfm_tm_getInitialDuration(document);
		infoMessage(4, "event_tm_saveLastDuration(): new default duration: " + duration);
		prefBranchOFMFunctionSettings.set("transfermarket.defaultduration", duration.toString());
	} catch (e) {
		errorMessage(e);
	}
}

/*******************************************************************************
 * Name of function:		foxfm_tm_defaultPrice()
 * Arguments of function:	document
 * Description of function:	This function manipulates the input field for the 
 *                          price of a player to be set on the transfer market.
 *                          If configured the actually submitted price will be 
 *                          saved as the new default price.
 */
function foxfm_tm_defaultPrice(document)
{
	try 
	{
		var addDefaultTMPrice	= prefBranchOFMFunctionSettings.get("transfermarket.adddefaultprice");
	
		if((document.location.href.match("010_mannschaft/spieler_anbieten_small.php") || 
		    document.location.href.match("010_transfer/angebote.php")) && addDefaultTMPrice) 
		{
			infoMessage(3, "foxfm_tm_defaultPrice(): started");
			
			// get default transfer marktet price from the preferences
			var defaultTMPrice	= getNumberFromString(foxfm_getPrefOFMTMDefaultPrice());
			
			// change OFM transfer market price
			foxfm_tm_setInitialPrice(document, defaultTMPrice);
			
			// save last used TM duration as default duration
			var saveLastPrice = prefBranchOFMFunctionSettings.get("transfermarket.defaultpricesavelast");
			if(saveLastPrice)
			{
				var TMSubmit = foxfm_tm_getElementSubmit(document);
				if(TMSubmit)
				{
					TMSubmit.addEventListener("mouseup", function(){event_tm_saveLastPrice(document)}, false);
				}
			}			
		}
	} catch (e) {
		errorMessage(e);
	}
}

function foxfm_tm_getInitialPrice(document)
{
	var initialPrice = null;
	try
	{
		infoMessage(4, "foxfm_tm_getInitialPrice(): started");

		var elementInitialPrice = foxfm_tm_getElementInitialPrice(document);
		if(elementInitialPrice)
		{
			initialPrice = getNumberFromString(elementInitialPrice.value);
			infoMessage(4, "foxfm_tm_getInitialPrice(): initial price: " + initialPrice);			
		}
	} catch (e) {
		errorMessage(e);
	}
	return initialPrice;
}

function foxfm_tm_setInitialPrice(document, price)
{
	try
	{
		var elementInitialPrice = foxfm_tm_getElementInitialPrice(document);
		if(elementInitialPrice)
		{
			elementInitialPrice.value = price;
		}
	} catch (e) {
		errorMessage(e);
	}
}

function foxfm_tm_getElementInitialPrice(document)
{
	var elementTMInputInitialPrice = null;
	try
	{
		infoMessage(4, "foxfm_tm_getElementInitialPrice(): started");

		if((document.location.href.match("010_mannschaft/spieler_anbieten_small.php") || 
		    document.location.href.match("010_transfer/angebote.php"))) 
		{
			var aInputs = document.getElementsByTagName("input");
			for(var i=0; i<aInputs.length; i++)
			{
				var aInputName= aInputs[i].name;
				infoMessage(4, "foxfm_tm_getElementInitialPrice(): aInputName: " + aInputName);
				if(aInputName.match("startpreis") || aInputName.match("angebot"))
				{
					elementTMInputInitialPrice = aInputs[i];
					break;
				}		
			}
		}
	} catch (e) {
		errorMessage(e);
	}	
	return elementTMInputInitialPrice;
}

function event_tm_saveLastPrice(document)
{
	try
	{
		infoMessage(4, "event_tm_saveLastPrice(): started");

		var price = foxfm_tm_getInitialPrice(document);
		infoMessage(4, "event_tm_saveLastPrice(): new default price: " + price);
		foxfm_setPrefOFMTMDefaultPrice(price.toString());
	} catch (e) {
		errorMessage(e);
	}
}

/*******************************************************************************
 * Name of function:		foxfm_tm_logbook()
 * Arguments of function:	document
 * Description of function:	This function fills the transfer market form
 *								- money
 *							of a player following certain rules:
 *
 */
function foxfm_tm_logbook(document)
{
	try 
	{
		var improvelogbook	= prefBranchOFMFunctionSettings.get("transfermarket.improvelogbook");
	
		if((document.location.href.match("010_buero/buero.php") || 
		    document.location.href.match("010_buero/buero_logbuch.php")) && improvelogbook) 
		{
			infoMessage(3, "foxfm_tm_logbook(): start");
			var logBook  = document.getElementById("logBook");
			logBook.addEventListener("mouseup", function(event){event_tm_logbookHandling(event)}, false );			
		}
	} catch (e) {
		errorMessage(e);
	}
}

function event_tm_logbookHandling(event)
{
	try
	{
		infoMessage(4, "event_tm_logbookHandling(): started");

		// 0 must indicate the primary button of the device (in general, the left button or the only button on single-button devices, used to activate a user interface control or select text).
		// 1 must indicate the auxiliary button (in general, the middle button, often combined with a mouse wheel).
		// 2 must indicate the secondary button (in general, the right button, often used to display a context menu).
		var mouseButton	= event.button;
		var targetNode	= event.target.nodeName;
		var altKey      = event.altKey;
		if(mouseButton==0)
		{
			infoMessage(4, "event_tm_logbookHandling(): mouse button: " + mouseButton + "; altKey?: " + altKey + "; target node:" + targetNode);
            /* Check if the mouse click event was at least activated on a link.
             * This ensures that not at every mouse click on the log book will
             * cause a change of the last transfer market price.
             */
            if(targetNode.match("A"))
            {            
                var innerhtml = event.target.parentNode.innerHTML;
                infoMessage(4, "event_tm_logbookHandling(): " + innerhtml);
                // get the position where to look for the last transfer market price
                var localeThePriceWas = foxfm_getLocale_thePriceWas();

                var searchString = new RegExp(localeThePriceWas);
                var priceStartPos = innerhtml.search(searchString) + searchString.source.length;
                infoMessage(4, priceStartPos);
                var lastTMPrice = getNumberFromString(innerhtml.slice(priceStartPos));
                infoMessage(4, "TM price: '" + lastTMPrice + "'");
                foxfm_setPrefOFMTMDefaultPrice(lastTMPrice.toString());
            }
		}
	} catch (e) {
		errorMessage(e);
	}
}